function(){return function(){function h(a){return function(){return this[a]}}function l(a){return function(){return a}}var n=this;
function aa(a){var b=typeof a;if("object"==b)if(a){if(a instanceof Array)return"array";if(a instanceof Object)return b;var c=Object.prototype.toString.call(a);if("[object Window]"==c)return"object";if("[object Array]"==c||"number"==typeof a.length&&"undefined"!=typeof a.splice&&"undefined"!=typeof a.propertyIsEnumerable&&!a.propertyIsEnumerable("splice"))return"array";if("[object Function]"==c||"undefined"!=typeof a.call&&"undefined"!=typeof a.propertyIsEnumerable&&!a.propertyIsEnumerable("call"))return"function"}else return"null";
else if("function"==b&&"undefined"==typeof a.call)return"object";return b}function ba(a){var b=aa(a);return"array"==b||"object"==b&&"number"==typeof a.length}function p(a){return"string"==typeof a}function ca(a){var b=typeof a;return"object"==b&&null!=a||"function"==b}function da(a,b,c){return a.call.apply(a.bind,arguments)}
function ea(a,b,c){if(!a)throw Error();if(2<arguments.length){var d=Array.prototype.slice.call(arguments,2);return function(){var c=Array.prototype.slice.call(arguments);Array.prototype.unshift.apply(c,d);return a.apply(b,c)}}return function(){return a.apply(b,arguments)}}function fa(a,b,c){fa=Function.prototype.bind&&-1!=Function.prototype.bind.toString().indexOf("native code")?da:ea;return fa.apply(null,arguments)}
function ga(a,b){var c=Array.prototype.slice.call(arguments,1);return function(){var b=Array.prototype.slice.call(arguments);b.unshift.apply(b,c);return a.apply(this,b)}}var ha=Date.now||function(){return+new Date};function s(a,b){function c(){}c.prototype=b.prototype;a.wa=b.prototype;a.prototype=new c};var ia=window;function ja(a,b){for(var c=0,d=String(a).replace(/^[\s\xa0]+|[\s\xa0]+$/g,"").split("."),e=String(b).replace(/^[\s\xa0]+|[\s\xa0]+$/g,"").split("."),f=Math.max(d.length,e.length),g=0;0==c&&g<f;g++){var k=d[g]||"",q=e[g]||"",K=RegExp("(\\d*)(\\D*)","g"),G=RegExp("(\\d*)(\\D*)","g");do{var r=K.exec(k)||["","",""],m=G.exec(q)||["","",""];if(0==r[0].length&&0==m[0].length)break;c=((0==r[1].length?0:parseInt(r[1],10))<(0==m[1].length?0:parseInt(m[1],10))?-1:(0==r[1].length?0:parseInt(r[1],10))>(0==m[1].length?
0:parseInt(m[1],10))?1:0)||((0==r[2].length)<(0==m[2].length)?-1:(0==r[2].length)>(0==m[2].length)?1:0)||(r[2]<m[2]?-1:r[2]>m[2]?1:0)}while(0==c)}return c}function ka(a){return String(a).replace(/\-([a-z])/g,function(a,c){return c.toUpperCase()})};var la=Array.prototype;function t(a,b){for(var c=a.length,d=p(a)?a.split(""):a,e=0;e<c;e++)e in d&&b.call(void 0,d[e],e,a)}function ma(a,b){for(var c=a.length,d=[],e=0,f=p(a)?a.split(""):a,g=0;g<c;g++)if(g in f){var k=f[g];b.call(void 0,k,g,a)&&(d[e++]=k)}return d}function na(a,b){for(var c=a.length,d=Array(c),e=p(a)?a.split(""):a,f=0;f<c;f++)f in e&&(d[f]=b.call(void 0,e[f],f,a));return d}
function oa(a,b,c){if(a.reduce)return a.reduce(b,c);var d=c;t(a,function(c,f){d=b.call(void 0,d,c,f,a)});return d}function pa(a,b){for(var c=a.length,d=p(a)?a.split(""):a,e=0;e<c;e++)if(e in d&&b.call(void 0,d[e],e,a))return!0;return!1}function qa(a,b){var c;a:{c=a.length;for(var d=p(a)?a.split(""):a,e=0;e<c;e++)if(e in d&&b.call(void 0,d[e],e,a)){c=e;break a}c=-1}return 0>c?null:p(a)?a.charAt(c):a[c]}
function ra(a,b){var c;a:if(p(a))c=p(b)&&1==b.length?a.indexOf(b,0):-1;else{for(c=0;c<a.length;c++)if(c in a&&a[c]===b)break a;c=-1}return 0<=c}function sa(a){return la.concat.apply(la,arguments)}function ta(a,b,c){return 2>=arguments.length?la.slice.call(a,b):la.slice.call(a,b,c)};var ua={aliceblue:"#f0f8ff",antiquewhite:"#faebd7",aqua:"#00ffff",aquamarine:"#7fffd4",azure:"#f0ffff",beige:"#f5f5dc",bisque:"#ffe4c4",black:"#000000",blanchedalmond:"#ffebcd",blue:"#0000ff",blueviolet:"#8a2be2",brown:"#a52a2a",burlywood:"#deb887",cadetblue:"#5f9ea0",chartreuse:"#7fff00",chocolate:"#d2691e",coral:"#ff7f50",cornflowerblue:"#6495ed",cornsilk:"#fff8dc",crimson:"#dc143c",cyan:"#00ffff",darkblue:"#00008b",darkcyan:"#008b8b",darkgoldenrod:"#b8860b",darkgray:"#a9a9a9",darkgreen:"#006400",
darkgrey:"#a9a9a9",darkkhaki:"#bdb76b",darkmagenta:"#8b008b",darkolivegreen:"#556b2f",darkorange:"#ff8c00",darkorchid:"#9932cc",darkred:"#8b0000",darksalmon:"#e9967a",darkseagreen:"#8fbc8f",darkslateblue:"#483d8b",darkslategray:"#2f4f4f",darkslategrey:"#2f4f4f",darkturquoise:"#00ced1",darkviolet:"#9400d3",deeppink:"#ff1493",deepskyblue:"#00bfff",dimgray:"#696969",dimgrey:"#696969",dodgerblue:"#1e90ff",firebrick:"#b22222",floralwhite:"#fffaf0",forestgreen:"#228b22",fuchsia:"#ff00ff",gainsboro:"#dcdcdc",
ghostwhite:"#f8f8ff",gold:"#ffd700",goldenrod:"#daa520",gray:"#808080",green:"#008000",greenyellow:"#adff2f",grey:"#808080",honeydew:"#f0fff0",hotpink:"#ff69b4",indianred:"#cd5c5c",indigo:"#4b0082",ivory:"#fffff0",khaki:"#f0e68c",lavender:"#e6e6fa",lavenderblush:"#fff0f5",lawngreen:"#7cfc00",lemonchiffon:"#fffacd",lightblue:"#add8e6",lightcoral:"#f08080",lightcyan:"#e0ffff",lightgoldenrodyellow:"#fafad2",lightgray:"#d3d3d3",lightgreen:"#90ee90",lightgrey:"#d3d3d3",lightpink:"#ffb6c1",lightsalmon:"#ffa07a",
lightseagreen:"#20b2aa",lightskyblue:"#87cefa",lightslategray:"#778899",lightslategrey:"#778899",lightsteelblue:"#b0c4de",lightyellow:"#ffffe0",lime:"#00ff00",limegreen:"#32cd32",linen:"#faf0e6",magenta:"#ff00ff",maroon:"#800000",mediumaquamarine:"#66cdaa",mediumblue:"#0000cd",mediumorchid:"#ba55d3",mediumpurple:"#9370db",mediumseagreen:"#3cb371",mediumslateblue:"#7b68ee",mediumspringgreen:"#00fa9a",mediumturquoise:"#48d1cc",mediumvioletred:"#c71585",midnightblue:"#191970",mintcream:"#f5fffa",mistyrose:"#ffe4e1",
moccasin:"#ffe4b5",navajowhite:"#ffdead",navy:"#000080",oldlace:"#fdf5e6",olive:"#808000",olivedrab:"#6b8e23",orange:"#ffa500",orangered:"#ff4500",orchid:"#da70d6",palegoldenrod:"#eee8aa",palegreen:"#98fb98",paleturquoise:"#afeeee",palevioletred:"#db7093",papayawhip:"#ffefd5",peachpuff:"#ffdab9",peru:"#cd853f",pink:"#ffc0cb",plum:"#dda0dd",powderblue:"#b0e0e6",purple:"#800080",red:"#ff0000",rosybrown:"#bc8f8f",royalblue:"#4169e1",saddlebrown:"#8b4513",salmon:"#fa8072",sandybrown:"#f4a460",seagreen:"#2e8b57",
seashell:"#fff5ee",sienna:"#a0522d",silver:"#c0c0c0",skyblue:"#87ceeb",slateblue:"#6a5acd",slategray:"#708090",slategrey:"#708090",snow:"#fffafa",springgreen:"#00ff7f",steelblue:"#4682b4",tan:"#d2b48c",teal:"#008080",thistle:"#d8bfd8",tomato:"#ff6347",turquoise:"#40e0d0",violet:"#ee82ee",wheat:"#f5deb3",white:"#ffffff",whitesmoke:"#f5f5f5",yellow:"#ffff00",yellowgreen:"#9acd32"};var va="backgroundColor borderTopColor borderRightColor borderBottomColor borderLeftColor color outlineColor".split(" "),wa=/#([0-9a-fA-F])([0-9a-fA-F])([0-9a-fA-F])/,xa=/^#(?:[0-9a-f]{3}){1,2}$/i,ya=/^(?:rgba)?\((\d{1,3}),\s?(\d{1,3}),\s?(\d{1,3}),\s?(0|1|0\.\d*)\)$/i,za=/^(?:rgb)?\((0|[1-9]\d{0,2}),\s?(0|[1-9]\d{0,2}),\s?(0|[1-9]\d{0,2})\)$/i;function Aa(a,b){this.code=a;this.state=Ba[a]||Ca;this.message=b||"";var c=this.state.replace(/((?:^|\s+)[a-z])/g,function(a){return a.toUpperCase().replace(/^[\s\xa0]+/g,"")}),d=c.length-5;if(0>d||c.indexOf("Error",d)!=d)c+="Error";this.name=c;c=Error(this.message);c.name=this.name;this.stack=c.stack||""}s(Aa,Error);
var Ca="unknown error",Ba={15:"element not selectable",11:"element not visible",31:"ime engine activation failed",30:"ime not available",24:"invalid cookie domain",29:"invalid element coordinates",12:"invalid element state",32:"invalid selector",51:"invalid selector",52:"invalid selector",17:"javascript error",405:"unsupported operation",34:"move target out of bounds",27:"no such alert",7:"no such element",8:"no such frame",23:"no such window",28:"script timeout",33:"session not created",10:"stale element reference",
0:"success",21:"timeout",25:"unable to set cookie",26:"unexpected alert open"};Ba[13]=Ca;Ba[9]="unknown command";Aa.prototype.toString=function(){return this.name+": "+this.message};var Da,Ha,Ia,Ja,Ka,La;function Ma(){return n.navigator?n.navigator.userAgent:null}Ja=Ia=Ha=Da=!1;var Na;if(Na=Ma()){var Oa=n.navigator;Da=0==Na.indexOf("Opera");Ha=!Da&&-1!=Na.indexOf("MSIE");Ia=!Da&&-1!=Na.indexOf("WebKit");Ja=!Da&&!Ia&&"Gecko"==Oa.product}var v=Da,w=Ha,x=Ja,Pa=Ia,Qa,Ra=n.navigator;Qa=Ra&&Ra.platform||"";Ka=-1!=Qa.indexOf("Mac");La=-1!=Qa.indexOf("Win");var Sa=-1!=Qa.indexOf("Linux");function Ta(){var a=n.document;return a?a.documentMode:void 0}var Ua;
a:{var Va="",Wa;if(v&&n.opera)var Xa=n.opera.version,Va="function"==typeof Xa?Xa():Xa;else if(x?Wa=/rv\:([^\);]+)(\)|;)/:w?Wa=/MSIE\s+([^\);]+)(\)|;)/:Pa&&(Wa=/WebKit\/(\S+)/),Wa)var Ya=Wa.exec(Ma()),Va=Ya?Ya[1]:"";if(w){var Za=Ta();if(Za>parseFloat(Va)){Ua=String(Za);break a}}Ua=Va}var $a={};function ab(a){return $a[a]||($a[a]=0<=ja(Ua,a))}var bb=n.document,cb=bb&&w?Ta()||("CSS1Compat"==bb.compatMode?parseInt(Ua,10):5):void 0;!x&&!w||w&&w&&9<=cb||x&&ab("1.9.1");w&&ab("9");function db(a,b){this.x=void 0!==a?a:0;this.y=void 0!==b?b:0}db.prototype.toString=function(){return"("+this.x+", "+this.y+")"};db.prototype.ceil=function(){this.x=Math.ceil(this.x);this.y=Math.ceil(this.y);return this};db.prototype.floor=function(){this.x=Math.floor(this.x);this.y=Math.floor(this.y);return this};db.prototype.round=function(){this.x=Math.round(this.x);this.y=Math.round(this.y);return this};function eb(a,b){this.width=a;this.height=b}eb.prototype.toString=function(){return"("+this.width+" x "+this.height+")"};eb.prototype.ceil=function(){this.width=Math.ceil(this.width);this.height=Math.ceil(this.height);return this};eb.prototype.floor=function(){this.width=Math.floor(this.width);this.height=Math.floor(this.height);return this};eb.prototype.round=function(){this.width=Math.round(this.width);this.height=Math.round(this.height);return this};function fb(a,b){var c={},d;for(d in a)b.call(void 0,a[d],d,a)&&(c[d]=a[d]);return c}function gb(a,b){var c={},d;for(d in a)c[d]=b.call(void 0,a[d],d,a);return c}function hb(a,b){for(var c in a)if(b.call(void 0,a[c],c,a))return c};function ib(a){a=a.document;a="CSS1Compat"==a.compatMode?a.documentElement:a.body;return new eb(a.clientWidth,a.clientHeight)}function jb(a,b){if(a.contains&&1==b.nodeType)return a==b||a.contains(b);if("undefined"!=typeof a.compareDocumentPosition)return a==b||Boolean(a.compareDocumentPosition(b)&16);for(;b&&a!=b;)b=b.parentNode;return b==a}
function kb(a,b){if(a==b)return 0;if(a.compareDocumentPosition)return a.compareDocumentPosition(b)&2?1:-1;if(w&&!(w&&9<=cb)){if(9==a.nodeType)return-1;if(9==b.nodeType)return 1}if("sourceIndex"in a||a.parentNode&&"sourceIndex"in a.parentNode){var c=1==a.nodeType,d=1==b.nodeType;if(c&&d)return a.sourceIndex-b.sourceIndex;var e=a.parentNode,f=b.parentNode;return e==f?lb(a,b):!c&&jb(e,b)?-1*mb(a,b):!d&&jb(f,a)?mb(b,a):(c?a.sourceIndex:e.sourceIndex)-(d?b.sourceIndex:f.sourceIndex)}d=y(a);c=d.createRange();
c.selectNode(a);c.collapse(!0);d=d.createRange();d.selectNode(b);d.collapse(!0);return c.compareBoundaryPoints(n.Range.START_TO_END,d)}function mb(a,b){var c=a.parentNode;if(c==b)return-1;for(var d=b;d.parentNode!=c;)d=d.parentNode;return lb(d,a)}function lb(a,b){for(var c=b;c=c.previousSibling;)if(c==a)return-1;return 1}function y(a){return 9==a.nodeType?a:a.ownerDocument||a.document}function nb(a){this.ia=a||n.document||document}nb.prototype.contains=jb;var ob,pb,qb,rb,sb,tb,ub;ub=tb=sb=rb=qb=pb=ob=!1;var z=Ma();z&&(-1!=z.indexOf("Firefox")?ob=!0:-1!=z.indexOf("Camino")?pb=!0:-1!=z.indexOf("iPhone")||-1!=z.indexOf("iPod")?qb=!0:-1!=z.indexOf("iPad")?rb=!0:-1!=z.indexOf("Android")?sb=!0:-1!=z.indexOf("Chrome")?tb=!0:-1!=z.indexOf("Safari")&&(ub=!0));var vb=ob,wb=pb,xb=qb,yb=rb,zb=sb,Ab=tb,Bb=ub;function Cb(a,b,c){this.e=a;this.pa=b||1;this.m=c||1};var B=w&&!(w&&9<=cb),Db=w&&!(w&&8<=cb);function Eb(a,b,c,d,e){this.e=a;this.nodeName=c;this.nodeValue=d;this.nodeType=2;this.ownerElement=b;this.ua=e;this.parentNode=b}function Fb(a,b,c){var d=Db&&"href"==b.nodeName?a.getAttribute(b.nodeName,2):b.nodeValue;return new Eb(b,a,b.nodeName,d,c)};function Gb(a){this.S=a;this.G=0}function Hb(a){a=a.match(Ib);for(var b=0;b<a.length;b++)Jb.test(a[b])&&a.splice(b,1);return new Gb(a)}var Ib=RegExp("\\$?(?:(?![0-9-])[\\w-]+:)?(?![0-9-])[\\w-]+|\\/\\/|\\.\\.|::|\\d+(?:\\.\\d*)?|\\.\\d+|\"[^\"]*\"|'[^']*'|[!<>]=|\\s+|.","g"),Jb=/^\s/;function C(a,b){return a.S[a.G+(b||0)]}Gb.prototype.next=function(){return this.S[this.G++]};Gb.prototype.back=function(){this.G--};Gb.prototype.empty=function(){return this.S.length<=this.G};function D(a){var b=null,c=a.nodeType;1==c&&(b=a.textContent,b=void 0==b||null==b?a.innerText:b,b=void 0==b||null==b?"":b);if("string"!=typeof b)if(B&&"title"==a.nodeName.toLowerCase()&&1==c)b=a.text;else if(9==c||1==c){a=9==c?a.documentElement:a.firstChild;for(var c=0,d=[],b="";a;){do 1!=a.nodeType&&(b+=a.nodeValue),B&&"title"==a.nodeName.toLowerCase()&&(b+=a.text),d[c++]=a;while(a=a.firstChild);for(;c&&!(a=d[--c].nextSibling););}}else b=a.nodeValue;return""+b}
function E(a,b,c){if(null===b)return!0;try{if(!a.getAttribute)return!1}catch(d){return!1}Db&&"class"==b&&(b="className");return null==c?!!a.getAttribute(b):a.getAttribute(b,2)==c}function Kb(a,b,c,d,e){return(B?Lb:Mb).call(null,a,b,p(c)?c:null,p(d)?d:null,e||new F)}
function Lb(a,b,c,d,e){if(a instanceof Nb||8==a.l||c&&null===a.l){var f=b.all;if(!f)return e;a=Ob(a);if("*"!=a&&(f=b.getElementsByTagName(a),!f))return e;if(c){for(var g=[],k=0;b=f[k++];)E(b,c,d)&&g.push(b);f=g}for(k=0;b=f[k++];)"*"==a&&"!"==b.tagName||e.add(b);return e}Pb(a,b,c,d,e);return e}
function Mb(a,b,c,d,e){b.getElementsByName&&d&&"name"==c&&!w?(b=b.getElementsByName(d),t(b,function(b){a.matches(b)&&e.add(b)})):b.getElementsByClassName&&d&&"class"==c?(b=b.getElementsByClassName(d),t(b,function(b){b.className==d&&a.matches(b)&&e.add(b)})):a instanceof H?Pb(a,b,c,d,e):b.getElementsByTagName&&(b=b.getElementsByTagName(a.getName()),t(b,function(a){E(a,c,d)&&e.add(a)}));return e}
function Qb(a,b,c,d,e){var f;if((a instanceof Nb||8==a.l||c&&null===a.l)&&(f=b.childNodes)){var g=Ob(a);if("*"!=g&&(f=ma(f,function(a){return a.tagName&&a.tagName.toLowerCase()==g}),!f))return e;c&&(f=ma(f,function(a){return E(a,c,d)}));t(f,function(a){"*"==g&&("!"==a.tagName||"*"==g&&1!=a.nodeType)||e.add(a)});return e}return Rb(a,b,c,d,e)}function Rb(a,b,c,d,e){for(b=b.firstChild;b;b=b.nextSibling)E(b,c,d)&&a.matches(b)&&e.add(b);return e}
function Pb(a,b,c,d,e){for(b=b.firstChild;b;b=b.nextSibling)E(b,c,d)&&a.matches(b)&&e.add(b),Pb(a,b,c,d,e)}function Ob(a){if(a instanceof H){if(8==a.l)return"!";if(null===a.l)return"*"}return a.getName()};function F(){this.m=this.i=null;this.B=0}function Sb(a){this.p=a;this.next=this.u=null}function Tb(a,b){if(!a.i)return b;if(!b.i)return a;for(var c=a.i,d=b.i,e=null,f=null,g=0;c&&d;)c.p==d.p||c.p instanceof Eb&&d.p instanceof Eb&&c.p.e==d.p.e?(f=c,c=c.next,d=d.next):0<kb(c.p,d.p)?(f=d,d=d.next):(f=c,c=c.next),(f.u=e)?e.next=f:a.i=f,e=f,g++;for(f=c||d;f;)f.u=e,e=e.next=f,g++,f=f.next;a.m=e;a.B=g;return a}
F.prototype.unshift=function(a){a=new Sb(a);a.next=this.i;this.m?this.i.u=a:this.i=this.m=a;this.i=a;this.B++};F.prototype.add=function(a){a=new Sb(a);a.u=this.m;this.i?this.m.next=a:this.i=this.m=a;this.m=a;this.B++};function Ub(a){return(a=a.i)?a.p:null}F.prototype.o=h("B");function Vb(a){return(a=Ub(a))?D(a):""}function I(a,b){return new Wb(a,!!b)}function Wb(a,b){this.la=a;this.T=(this.v=b)?a.m:a.i;this.N=null}
Wb.prototype.next=function(){var a=this.T;if(null==a)return null;var b=this.N=a;this.T=this.v?a.u:a.next;return b.p};Wb.prototype.remove=function(){var a=this.la,b=this.N;if(!b)throw Error("Next must be called at least once before remove.");var c=b.u,b=b.next;c?c.next=b:a.i=b;b?b.u=c:a.m=c;a.B--;this.N=null};function J(a){this.h=a;this.j=this.q=!1;this.C=null}function L(a){return"\n  "+a.toString().split("\n").join("\n  ")}J.prototype.f=h("q");function Xb(a,b){a.q=b}function Yb(a,b){a.j=b}J.prototype.s=h("C");function M(a,b){var c=a.evaluate(b);return c instanceof F?+Vb(c):+c}function N(a,b){var c=a.evaluate(b);return c instanceof F?Vb(c):""+c}function Zb(a,b){var c=a.evaluate(b);return c instanceof F?!!c.o():!!c};function $b(a,b,c){J.call(this,a.h);this.R=a;this.W=b;this.aa=c;this.q=b.f()||c.f();this.j=b.j||c.j;this.R==ac&&(c.j||c.f()||4==c.h||0==c.h||!b.s()?b.j||(b.f()||4==b.h||0==b.h||!c.s())||(this.C={name:c.s().name,w:b}):this.C={name:b.s().name,w:c})}s($b,J);
function bc(a,b,c,d,e){b=b.evaluate(d);c=c.evaluate(d);var f;if(b instanceof F&&c instanceof F){e=I(b);for(d=e.next();d;d=e.next())for(b=I(c),f=b.next();f;f=b.next())if(a(D(d),D(f)))return!0;return!1}if(b instanceof F||c instanceof F){b instanceof F?e=b:(e=c,c=b);e=I(e);b=typeof c;for(d=e.next();d;d=e.next()){switch(b){case "number":d=+D(d);break;case "boolean":d=!!D(d);break;case "string":d=D(d);break;default:throw Error("Illegal primitive type for comparison.");}if(a(d,c))return!0}return!1}return e?
"boolean"==typeof b||"boolean"==typeof c?a(!!b,!!c):"number"==typeof b||"number"==typeof c?a(+b,+c):a(b,c):a(+b,+c)}$b.prototype.evaluate=function(a){return this.R.n(this.W,this.aa,a)};$b.prototype.toString=function(){var a="Binary Expression: "+this.R,a=a+L(this.W);return a+=L(this.aa)};function cc(a,b,c,d){this.oa=a;this.Z=b;this.h=c;this.n=d}cc.prototype.toString=h("oa");var dc={};
function O(a,b,c,d){if(dc.hasOwnProperty(a))throw Error("Binary operator already created: "+a);a=new cc(a,b,c,d);return dc[a.toString()]=a}O("div",6,1,function(a,b,c){return M(a,c)/M(b,c)});O("mod",6,1,function(a,b,c){return M(a,c)%M(b,c)});O("*",6,1,function(a,b,c){return M(a,c)*M(b,c)});O("+",5,1,function(a,b,c){return M(a,c)+M(b,c)});O("-",5,1,function(a,b,c){return M(a,c)-M(b,c)});O("<",4,2,function(a,b,c){return bc(function(a,b){return a<b},a,b,c)});
O(">",4,2,function(a,b,c){return bc(function(a,b){return a>b},a,b,c)});O("<=",4,2,function(a,b,c){return bc(function(a,b){return a<=b},a,b,c)});O(">=",4,2,function(a,b,c){return bc(function(a,b){return a>=b},a,b,c)});var ac=O("=",3,2,function(a,b,c){return bc(function(a,b){return a==b},a,b,c,!0)});O("!=",3,2,function(a,b,c){return bc(function(a,b){return a!=b},a,b,c,!0)});O("and",2,2,function(a,b,c){return Zb(a,c)&&Zb(b,c)});O("or",1,2,function(a,b,c){return Zb(a,c)||Zb(b,c)});function ec(a,b){if(b.o()&&4!=a.h)throw Error("Primary expression must evaluate to nodeset if filter has predicate(s).");J.call(this,a.h);this.$=a;this.d=b;this.q=a.f();this.j=a.j}s(ec,J);ec.prototype.evaluate=function(a){a=this.$.evaluate(a);return fc(this.d,a)};ec.prototype.toString=function(){var a;a="Filter:"+L(this.$);return a+=L(this.d)};function gc(a,b){if(b.length<a.Y)throw Error("Function "+a.k+" expects at least"+a.Y+" arguments, "+b.length+" given");if(null!==a.O&&b.length>a.O)throw Error("Function "+a.k+" expects at most "+a.O+" arguments, "+b.length+" given");a.ma&&t(b,function(b,d){if(4!=b.h)throw Error("Argument "+d+" to function "+a.k+" is not of type Nodeset: "+b);});J.call(this,a.h);this.F=a;this.K=b;Xb(this,a.q||pa(b,function(a){return a.f()}));Yb(this,a.ka&&!b.length||a.ja&&!!b.length||pa(b,function(a){return a.j}))}
s(gc,J);gc.prototype.evaluate=function(a){return this.F.n.apply(null,sa(a,this.K))};gc.prototype.toString=function(){var a="Function: "+this.F;if(this.K.length)var b=oa(this.K,function(a,b){return a+L(b)},"Arguments:"),a=a+L(b);return a};function hc(a,b,c,d,e,f,g,k,q){this.k=a;this.h=b;this.q=c;this.ka=d;this.ja=e;this.n=f;this.Y=g;this.O=void 0!==k?k:g;this.ma=!!q}hc.prototype.toString=h("k");var ic={};
function Q(a,b,c,d,e,f,g,k){if(ic.hasOwnProperty(a))throw Error("Function already created: "+a+".");ic[a]=new hc(a,b,c,d,!1,e,f,g,k)}Q("boolean",2,!1,!1,function(a,b){return Zb(b,a)},1);Q("ceiling",1,!1,!1,function(a,b){return Math.ceil(M(b,a))},1);Q("concat",3,!1,!1,function(a,b){var c=ta(arguments,1);return oa(c,function(b,c){return b+N(c,a)},"")},2,null);Q("contains",2,!1,!1,function(a,b,c){b=N(b,a);a=N(c,a);return-1!=b.indexOf(a)},2);
Q("count",1,!1,!1,function(a,b){return b.evaluate(a).o()},1,1,!0);Q("false",2,!1,!1,l(!1),0);Q("floor",1,!1,!1,function(a,b){return Math.floor(M(b,a))},1);
Q("id",4,!1,!1,function(a,b){function c(a){if(B){var b=e.all[a];if(b){if(b.nodeType&&a==b.id)return b;if(b.length)return qa(b,function(b){return a==b.id})}return null}return e.getElementById(a)}var d=a.e,e=9==d.nodeType?d:d.ownerDocument,d=N(b,a).split(/\s+/),f=[];t(d,function(a){(a=c(a))&&!ra(f,a)&&f.push(a)});f.sort(kb);var g=new F;t(f,function(a){g.add(a)});return g},1);Q("lang",2,!1,!1,l(!1),1);
Q("last",1,!0,!1,function(a){if(1!=arguments.length)throw Error("Function last expects ()");return a.m},0);Q("local-name",3,!1,!0,function(a,b){var c=b?Ub(b.evaluate(a)):a.e;return c?c.nodeName.toLowerCase():""},0,1,!0);Q("name",3,!1,!0,function(a,b){var c=b?Ub(b.evaluate(a)):a.e;return c?c.nodeName.toLowerCase():""},0,1,!0);Q("namespace-uri",3,!0,!1,l(""),0,1,!0);Q("normalize-space",3,!1,!0,function(a,b){return(b?N(b,a):D(a.e)).replace(/[\s\xa0]+/g," ").replace(/^\s+|\s+$/g,"")},0,1);
Q("not",2,!1,!1,function(a,b){return!Zb(b,a)},1);Q("number",1,!1,!0,function(a,b){return b?M(b,a):+D(a.e)},0,1);Q("position",1,!0,!1,function(a){return a.pa},0);Q("round",1,!1,!1,function(a,b){return Math.round(M(b,a))},1);Q("starts-with",2,!1,!1,function(a,b,c){b=N(b,a);a=N(c,a);return 0==b.lastIndexOf(a,0)},2);Q("string",3,!1,!0,function(a,b){return b?N(b,a):D(a.e)},0,1);Q("string-length",1,!1,!0,function(a,b){return(b?N(b,a):D(a.e)).length},0,1);
Q("substring",3,!1,!1,function(a,b,c,d){c=M(c,a);if(isNaN(c)||Infinity==c||-Infinity==c)return"";d=d?M(d,a):Infinity;if(isNaN(d)||-Infinity===d)return"";c=Math.round(c)-1;var e=Math.max(c,0);a=N(b,a);if(Infinity==d)return a.substring(e);b=Math.round(d);return a.substring(e,c+b)},2,3);Q("substring-after",3,!1,!1,function(a,b,c){b=N(b,a);a=N(c,a);c=b.indexOf(a);return-1==c?"":b.substring(c+a.length)},2);
Q("substring-before",3,!1,!1,function(a,b,c){b=N(b,a);a=N(c,a);a=b.indexOf(a);return-1==a?"":b.substring(0,a)},2);Q("sum",1,!1,!1,function(a,b){for(var c=I(b.evaluate(a)),d=0,e=c.next();e;e=c.next())d+=+D(e);return d},1,1,!0);Q("translate",3,!1,!1,function(a,b,c,d){b=N(b,a);c=N(c,a);var e=N(d,a);a=[];for(d=0;d<c.length;d++){var f=c.charAt(d);f in a||(a[f]=e.charAt(d))}c="";for(d=0;d<b.length;d++)f=b.charAt(d),c+=f in a?a[f]:f;return c},3);Q("true",2,!1,!1,l(!0),0);function H(a,b){this.ca=a;this.X=void 0!==b?b:null;this.l=null;switch(a){case "comment":this.l=8;break;case "text":this.l=3;break;case "processing-instruction":this.l=7;break;case "node":break;default:throw Error("Unexpected argument");}}function jc(a){return"comment"==a||"text"==a||"processing-instruction"==a||"node"==a}H.prototype.matches=function(a){return null===this.l||this.l==a.nodeType};H.prototype.getName=h("ca");
H.prototype.toString=function(){var a="Kind Test: "+this.ca;null===this.X||(a+=L(this.X));return a};function kc(a){J.call(this,3);this.ba=a.substring(1,a.length-1)}s(kc,J);kc.prototype.evaluate=h("ba");kc.prototype.toString=function(){return"Literal: "+this.ba};function Nb(a,b){this.k=a.toLowerCase();this.P=b?b.toLowerCase():"http://www.w3.org/1999/xhtml"}Nb.prototype.matches=function(a){var b=a.nodeType;return 1!=b&&2!=b?!1:"*"!=this.k&&this.k!=a.nodeName.toLowerCase()?!1:this.P==(a.namespaceURI?a.namespaceURI.toLowerCase():"http://www.w3.org/1999/xhtml")};Nb.prototype.getName=h("k");Nb.prototype.toString=function(){return"Name Test: "+("http://www.w3.org/1999/xhtml"==this.P?"":this.P+":")+this.k};function lc(a){J.call(this,1);this.da=a}s(lc,J);lc.prototype.evaluate=h("da");lc.prototype.toString=function(){return"Number: "+this.da};function mc(a,b){J.call(this,a.h);this.V=a;this.D=b;this.q=a.f();this.j=a.j;if(1==this.D.length){var c=this.D[0];c.M||c.r!=nc||(c=c.J,"*"!=c.getName()&&(this.C={name:c.getName(),w:null}))}}s(mc,J);function oc(){J.call(this,4)}s(oc,J);oc.prototype.evaluate=function(a){var b=new F;a=a.e;9==a.nodeType?b.add(a):b.add(a.ownerDocument);return b};oc.prototype.toString=l("Root Helper Expression");function pc(){J.call(this,4)}s(pc,J);pc.prototype.evaluate=function(a){var b=new F;b.add(a.e);return b};
pc.prototype.toString=l("Context Helper Expression");
mc.prototype.evaluate=function(a){var b=this.V.evaluate(a);if(!(b instanceof F))throw Error("Filter expression must evaluate to nodeset.");a=this.D;for(var c=0,d=a.length;c<d&&b.o();c++){var e=a[c],f=I(b,e.r.v),g;if(e.f()||e.r!=qc)if(e.f()||e.r!=rc)for(g=f.next(),b=e.evaluate(new Cb(g));null!=(g=f.next());)g=e.evaluate(new Cb(g)),b=Tb(b,g);else g=f.next(),b=e.evaluate(new Cb(g));else{for(g=f.next();(b=f.next())&&(!g.contains||g.contains(b))&&b.compareDocumentPosition(g)&8;g=b);b=e.evaluate(new Cb(g))}}return b};
mc.prototype.toString=function(){var a;a="Path Expression:"+L(this.V);if(this.D.length){var b=oa(this.D,function(a,b){return a+L(b)},"Steps:");a+=L(b)}return a};function sc(a,b){this.d=a;this.v=!!b}function fc(a,b,c){for(c=c||0;c<a.d.length;c++)for(var d=a.d[c],e=I(b),f=b.o(),g,k=0;g=e.next();k++){var q=a.v?f-k:k+1;g=d.evaluate(new Cb(g,q,f));if("number"==typeof g)q=q==g;else if("string"==typeof g||"boolean"==typeof g)q=!!g;else if(g instanceof F)q=0<g.o();else throw Error("Predicate.evaluate returned an unexpected type.");q||e.remove()}return b}sc.prototype.s=function(){return 0<this.d.length?this.d[0].s():null};
sc.prototype.f=function(){for(var a=0;a<this.d.length;a++){var b=this.d[a];if(b.f()||1==b.h||0==b.h)return!0}return!1};sc.prototype.o=function(){return this.d.length};sc.prototype.toString=function(){return oa(this.d,function(a,b){return a+L(b)},"Predicates:")};function R(a,b,c,d){J.call(this,4);this.r=a;this.J=b;this.d=c||new sc([]);this.M=!!d;b=this.d.s();a.ra&&b&&(a=b.name,a=B?a.toLowerCase():a,this.C={name:a,w:b.w});this.q=this.d.f()}s(R,J);
R.prototype.evaluate=function(a){var b=a.e,c=null,c=this.s(),d=null,e=null,f=0;c&&(d=c.name,e=c.w?N(c.w,a):null,f=1);if(this.M)if(this.f()||this.r!=tc)if(a=I((new R(uc,new H("node"))).evaluate(a)),b=a.next())for(c=this.n(b,d,e,f);null!=(b=a.next());)c=Tb(c,this.n(b,d,e,f));else c=new F;else c=Kb(this.J,b,d,e),c=fc(this.d,c,f);else c=this.n(a.e,d,e,f);return c};R.prototype.n=function(a,b,c,d){a=this.r.F(this.J,a,b,c);return a=fc(this.d,a,d)};
R.prototype.toString=function(){var a;a="Step:"+L("Operator: "+(this.M?"//":"/"));this.r.k&&(a+=L("Axis: "+this.r));a+=L(this.J);if(this.d.o()){var b=oa(this.d.d,function(a,b){return a+L(b)},"Predicates:");a+=L(b)}return a};function vc(a,b,c,d){this.k=a;this.F=b;this.v=c;this.ra=d}vc.prototype.toString=h("k");var wc={};function S(a,b,c,d){if(wc.hasOwnProperty(a))throw Error("Axis already created: "+a);b=new vc(a,b,c,!!d);return wc[a]=b}
S("ancestor",function(a,b){for(var c=new F,d=b;d=d.parentNode;)a.matches(d)&&c.unshift(d);return c},!0);S("ancestor-or-self",function(a,b){var c=new F,d=b;do a.matches(d)&&c.unshift(d);while(d=d.parentNode);return c},!0);
var nc=S("attribute",function(a,b){var c=new F,d=a.getName();if("style"==d&&b.style&&B)return c.add(new Eb(b.style,b,"style",b.style.cssText,b.sourceIndex)),c;var e=b.attributes;if(e)if(a instanceof H&&null===a.l||"*"==d)for(var d=b.sourceIndex,f=0,g;g=e[f];f++)B?g.nodeValue&&c.add(Fb(b,g,d)):c.add(g);else(g=e.getNamedItem(d))&&(B?g.nodeValue&&c.add(Fb(b,g,b.sourceIndex)):c.add(g));return c},!1),tc=S("child",function(a,b,c,d,e){return(B?Qb:Rb).call(null,a,b,p(c)?c:null,p(d)?d:null,e||new F)},!1,!0);
S("descendant",Kb,!1,!0);var uc=S("descendant-or-self",function(a,b,c,d){var e=new F;E(b,c,d)&&a.matches(b)&&e.add(b);return Kb(a,b,c,d,e)},!1,!0),qc=S("following",function(a,b,c,d){var e=new F;do for(var f=b;f=f.nextSibling;)E(f,c,d)&&a.matches(f)&&e.add(f),e=Kb(a,f,c,d,e);while(b=b.parentNode);return e},!1,!0);S("following-sibling",function(a,b){for(var c=new F,d=b;d=d.nextSibling;)a.matches(d)&&c.add(d);return c},!1);S("namespace",function(){return new F},!1);
var xc=S("parent",function(a,b){var c=new F;if(9==b.nodeType)return c;if(2==b.nodeType)return c.add(b.ownerElement),c;var d=b.parentNode;a.matches(d)&&c.add(d);return c},!1),rc=S("preceding",function(a,b,c,d){var e=new F,f=[];do f.unshift(b);while(b=b.parentNode);for(var g=1,k=f.length;g<k;g++){var q=[];for(b=f[g];b=b.previousSibling;)q.unshift(b);for(var K=0,G=q.length;K<G;K++)b=q[K],E(b,c,d)&&a.matches(b)&&e.add(b),e=Kb(a,b,c,d,e)}return e},!0,!0);
S("preceding-sibling",function(a,b){for(var c=new F,d=b;d=d.previousSibling;)a.matches(d)&&c.unshift(d);return c},!0);var yc=S("self",function(a,b){var c=new F;a.matches(b)&&c.add(b);return c},!1);function zc(a){J.call(this,1);this.U=a;this.q=a.f();this.j=a.j}s(zc,J);zc.prototype.evaluate=function(a){return-M(this.U,a)};zc.prototype.toString=function(){return"Unary Expression: -"+L(this.U)};function Ac(a){J.call(this,4);this.H=a;Xb(this,pa(this.H,function(a){return a.f()}));Yb(this,pa(this.H,function(a){return a.j}))}s(Ac,J);Ac.prototype.evaluate=function(a){var b=new F;t(this.H,function(c){c=c.evaluate(a);if(!(c instanceof F))throw Error("Path expression must evaluate to NodeSet.");b=Tb(b,c)});return b};Ac.prototype.toString=function(){return oa(this.H,function(a,b){return a+L(b)},"Union Expression:")};function Bc(a,b){this.a=a;this.na=b}function Cc(a){for(var b,c=[];;){T(a,"Missing right hand side of binary expression.");b=Dc(a);var d=a.a.next();if(!d)break;var e=(d=dc[d]||null)&&d.Z;if(!e){a.a.back();break}for(;c.length&&e<=c[c.length-1].Z;)b=new $b(c.pop(),c.pop(),b);c.push(b,d)}for(;c.length;)b=new $b(c.pop(),c.pop(),b);return b}function T(a,b){if(a.a.empty())throw Error(b);}function Ec(a,b){var c=a.a.next();if(c!=b)throw Error("Bad token, expected: "+b+" got: "+c);}
function Fc(a){a=a.a.next();if(")"!=a)throw Error("Bad token: "+a);}function Gc(a){a=a.a.next();if(2>a.length)throw Error("Unclosed literal string");return new kc(a)}function Hc(a){var b=a.a.next(),c=b.indexOf(":");if(-1==c)return new Nb(b);var d=b.substring(0,c);a=a.na(d);if(!a)throw Error("Namespace prefix not declared: "+d);b=b.substr(c+1);return new Nb(b,a)}
function Ic(a){var b,c=[],d;if("/"==C(a.a)||"//"==C(a.a)){b=a.a.next();d=C(a.a);if("/"==b&&(a.a.empty()||"."!=d&&".."!=d&&"@"!=d&&"*"!=d&&!/(?![0-9])[\w]/.test(d)))return new oc;d=new oc;T(a,"Missing next location step.");b=Jc(a,b);c.push(b)}else{a:{b=C(a.a);d=b.charAt(0);switch(d){case "$":throw Error("Variable reference not allowed in HTML XPath");case "(":a.a.next();b=Cc(a);T(a,'unclosed "("');Ec(a,")");break;case '"':case "'":b=Gc(a);break;default:if(isNaN(+b))if(!jc(b)&&/(?![0-9])[\w]/.test(d)&&
"("==C(a.a,1)){b=a.a.next();b=ic[b]||null;a.a.next();for(d=[];")"!=C(a.a);){T(a,"Missing function argument list.");d.push(Cc(a));if(","!=C(a.a))break;a.a.next()}T(a,"Unclosed function argument list.");Fc(a);b=new gc(b,d)}else{b=null;break a}else b=new lc(+a.a.next())}"["==C(a.a)&&(d=new sc(Kc(a)),b=new ec(b,d))}if(b)if("/"==C(a.a)||"//"==C(a.a))d=b;else return b;else b=Jc(a,"/"),d=new pc,c.push(b)}for(;"/"==C(a.a)||"//"==C(a.a);)b=a.a.next(),T(a,"Missing next location step."),b=Jc(a,b),c.push(b);
return new mc(d,c)}
function Jc(a,b){var c,d,e;if("/"!=b&&"//"!=b)throw Error('Step op should be "/" or "//"');if("."==C(a.a))return d=new R(yc,new H("node")),a.a.next(),d;if(".."==C(a.a))return d=new R(xc,new H("node")),a.a.next(),d;var f;if("@"==C(a.a))f=nc,a.a.next(),T(a,"Missing attribute name");else if("::"==C(a.a,1)){if(!/(?![0-9])[\w]/.test(C(a.a).charAt(0)))throw Error("Bad token: "+a.a.next());c=a.a.next();f=wc[c]||null;if(!f)throw Error("No axis with name: "+c);a.a.next();T(a,"Missing node name")}else f=tc;
c=C(a.a);if(/(?![0-9])[\w]/.test(c.charAt(0)))if("("==C(a.a,1)){if(!jc(c))throw Error("Invalid node type: "+c);c=a.a.next();if(!jc(c))throw Error("Invalid type name: "+c);Ec(a,"(");T(a,"Bad nodetype");e=C(a.a).charAt(0);var g=null;if('"'==e||"'"==e)g=Gc(a);T(a,"Bad nodetype");Fc(a);c=new H(c,g)}else c=Hc(a);else if("*"==c)c=Hc(a);else throw Error("Bad token: "+a.a.next());e=new sc(Kc(a),f.v);return d||new R(f,c,e,"//"==b)}
function Kc(a){for(var b=[];"["==C(a.a);){a.a.next();T(a,"Missing predicate expression.");var c=Cc(a);b.push(c);T(a,"Unclosed predicate expression.");Ec(a,"]")}return b}function Dc(a){if("-"==C(a.a))return a.a.next(),new zc(Dc(a));var b=Ic(a);if("|"!=C(a.a))a=b;else{for(b=[b];"|"==a.a.next();)T(a,"Missing next union location path."),b.push(Ic(a));a.a.back();a=new Ac(b)}return a};function Lc(a){switch(a.nodeType){case 1:return ga(Mc,a);case 9:return Lc(a.documentElement);case 2:return a.ownerElement?Lc(a.ownerElement):Nc;case 11:case 10:case 6:case 12:return Nc;default:return a.parentNode?Lc(a.parentNode):Nc}}function Nc(){return null}function Mc(a,b){if(a.prefix==b)return a.namespaceURI||"http://www.w3.org/1999/xhtml";var c=a.getAttributeNode("xmlns:"+b);return c&&c.specified?c.value||null:a.parentNode&&9!=a.parentNode.nodeType?Mc(a.parentNode,b):null};function Oc(a,b){if(!a.length)throw Error("Empty XPath expression.");var c=Hb(a);if(c.empty())throw Error("Invalid XPath expression.");b?"function"==aa(b)||(b=fa(b.lookupNamespaceURI,b)):b=l(null);var d=Cc(new Bc(c,b));if(!c.empty())throw Error("Bad token: "+c.next());this.evaluate=function(a,b){var c=d.evaluate(new Cb(a));return new U(c,b)}}
function U(a,b){if(0==b)if(a instanceof F)b=4;else if("string"==typeof a)b=2;else if("number"==typeof a)b=1;else if("boolean"==typeof a)b=3;else throw Error("Unexpected evaluation result.");if(2!=b&&1!=b&&3!=b&&!(a instanceof F))throw Error("value could not be converted to the specified type");this.resultType=b;var c;switch(b){case 2:this.stringValue=a instanceof F?Vb(a):""+a;break;case 1:this.numberValue=a instanceof F?+Vb(a):+a;break;case 3:this.booleanValue=a instanceof F?0<a.o():!!a;break;case 4:case 5:case 6:case 7:var d=
I(a);c=[];for(var e=d.next();e;e=d.next())c.push(e instanceof Eb?e.e:e);this.snapshotLength=a.o();this.invalidIteratorState=!1;break;case 8:case 9:d=Ub(a);this.singleNodeValue=d instanceof Eb?d.e:d;break;default:throw Error("Unknown XPathResult type.");}var f=0;this.iterateNext=function(){if(4!=b&&5!=b)throw Error("iterateNext called with wrong result type");return f>=c.length?null:c[f++]};this.snapshotItem=function(a){if(6!=b&&7!=b)throw Error("snapshotItem called with wrong result type");return a>=
c.length||0>a?null:c[a]}}U.ANY_TYPE=0;U.NUMBER_TYPE=1;U.STRING_TYPE=2;U.BOOLEAN_TYPE=3;U.UNORDERED_NODE_ITERATOR_TYPE=4;U.ORDERED_NODE_ITERATOR_TYPE=5;U.UNORDERED_NODE_SNAPSHOT_TYPE=6;U.ORDERED_NODE_SNAPSHOT_TYPE=7;U.ANY_UNORDERED_NODE_TYPE=8;U.FIRST_ORDERED_NODE_TYPE=9;function Pc(a){this.lookupNamespaceURI=Lc(a)}
function Qc(a){a=a||n;var b=a.document;b.evaluate||(a.XPathResult=U,b.evaluate=function(a,b,e,f){return(new Oc(a,e)).evaluate(b,f)},b.createExpression=function(a,b){return new Oc(a,b)},b.createNSResolver=function(a){return new Pc(a)})};var V={};V.fa=function(){var a={xa:"http://www.w3.org/2000/svg"};return function(b){return a[b]||null}}();V.n=function(a,b,c){var d=y(a);(w||zb)&&Qc(d?d.parentWindow||d.defaultView:window);try{var e=d.createNSResolver?d.createNSResolver(d.documentElement):V.fa;return w&&!ab(7)?d.evaluate.call(d,b,a,e,c,null):d.evaluate(b,a,e,c,null)}catch(f){if(!x||"NS_ERROR_ILLEGAL_VALUE"!=f.name)throw new Aa(32,"Unable to locate an element with the xpath expression "+b+" because of the following error:\n"+f);}};
V.L=function(a,b){if(!a||1!=a.nodeType)throw new Aa(32,'The result of the xpath expression "'+b+'" is: '+a+". It should be an element.");};V.qa=function(a,b){var c=function(){var c=V.n(b,a,9);return c?(c=c.singleNodeValue,v?c:c||null):b.selectSingleNode?(c=y(b),c.setProperty&&c.setProperty("SelectionLanguage","XPath"),b.selectSingleNode(a)):null}();null===c||V.L(c,a);return c};
V.ta=function(a,b){var c=function(){var c=V.n(b,a,7);if(c){var e=c.snapshotLength;v&&void 0===e&&V.L(null,a);for(var f=[],g=0;g<e;++g)f.push(c.snapshotItem(g));return f}return b.selectNodes?(c=y(b),c.setProperty&&c.setProperty("SelectionLanguage","XPath"),b.selectNodes(a)):[]}();t(c,function(b){V.L(b,a)});return c};function Rc(a){return(a=a.exec(Ma()))?a[1]:""}var Sc=function(){if(vb)return Rc(/Firefox\/([0-9.]+)/);if(w||v)return Ua;if(Ab)return Rc(/Chrome\/([0-9.]+)/);if(Bb)return Rc(/Version\/([0-9.]+)/);if(xb||yb){var a=/Version\/(\S+).*Mobile\/(\S+)/.exec(Ma());if(a)return a[1]+"."+a[2]}else{if(zb)return(a=Rc(/Android\s+([0-9.]+)/))?a:Rc(/Version\/([0-9.]+)/);if(wb)return Rc(/Camino\/([0-9.]+)/)}return""}();var Tc,Uc;function Vc(a){return Wc?Tc(a):w?0<=ja(cb,a):ab(a)}function Xc(a){Wc?Uc(a):zb?ja(Yc,a):ja(Sc,a)}
var Wc=function(){if(!x)return!1;var a=n.Components;if(!a)return!1;try{if(!a.classes)return!1}catch(b){return!1}var c=a.classes,a=a.interfaces,d=c["@mozilla.org/xpcom/version-comparator;1"].getService(a.nsIVersionComparator),c=c["@mozilla.org/xre/app-info;1"].getService(a.nsIXULAppInfo),e=c.platformVersion,f=c.version;Tc=function(a){return 0<=d.ha(e,""+a)};Uc=function(a){d.ha(f,""+a)};return!0}(),Zc;if(zb){var $c=/Android\s+([0-9\.]+)/.exec(Ma());Zc=$c?$c[1]:"0"}else Zc="0";
var Yc=Zc,ad=w&&!(w&&9<=cb);zb&&Xc(2.3);zb&&Xc(4);Bb&&Xc(6);function W(a,b,c,d){this.top=a;this.right=b;this.bottom=c;this.left=d}W.prototype.toString=function(){return"("+this.top+"t, "+this.right+"r, "+this.bottom+"b, "+this.left+"l)"};W.prototype.contains=function(a){return this&&a?a instanceof W?a.left>=this.left&&a.right<=this.right&&a.top>=this.top&&a.bottom<=this.bottom:a.x>=this.left&&a.x<=this.right&&a.y>=this.top&&a.y<=this.bottom:!1};
W.prototype.ceil=function(){this.top=Math.ceil(this.top);this.right=Math.ceil(this.right);this.bottom=Math.ceil(this.bottom);this.left=Math.ceil(this.left);return this};W.prototype.floor=function(){this.top=Math.floor(this.top);this.right=Math.floor(this.right);this.bottom=Math.floor(this.bottom);this.left=Math.floor(this.left);return this};
W.prototype.round=function(){this.top=Math.round(this.top);this.right=Math.round(this.right);this.bottom=Math.round(this.bottom);this.left=Math.round(this.left);return this};function X(a,b,c,d){this.left=a;this.top=b;this.width=c;this.height=d}X.prototype.toString=function(){return"("+this.left+", "+this.top+" - "+this.width+"w x "+this.height+"h)"};X.prototype.contains=function(a){return a instanceof X?this.left<=a.left&&this.left+this.width>=a.left+a.width&&this.top<=a.top&&this.top+this.height>=a.top+a.height:a.x>=this.left&&a.x<=this.left+this.width&&a.y>=this.top&&a.y<=this.top+this.height};
X.prototype.ceil=function(){this.left=Math.ceil(this.left);this.top=Math.ceil(this.top);this.width=Math.ceil(this.width);this.height=Math.ceil(this.height);return this};X.prototype.floor=function(){this.left=Math.floor(this.left);this.top=Math.floor(this.top);this.width=Math.floor(this.width);this.height=Math.floor(this.height);return this};
X.prototype.round=function(){this.left=Math.round(this.left);this.top=Math.round(this.top);this.width=Math.round(this.width);this.height=Math.round(this.height);return this};function bd(a,b){var c=y(a);return c.defaultView&&c.defaultView.getComputedStyle&&(c=c.defaultView.getComputedStyle(a,null))?c[b]||c.getPropertyValue(b)||"":""}var cd={thin:2,medium:4,thick:6};
function dd(a,b){if("none"==(a.currentStyle?a.currentStyle[b+"Style"]:null))return 0;var c=a.currentStyle?a.currentStyle[b+"Width"]:null,d;if(c in cd)d=cd[c];else if(/^\d+px?$/.test(c))d=parseInt(c,10);else{d=a.style.left;var e=a.runtimeStyle.left;a.runtimeStyle.left=a.currentStyle.left;a.style.left=c;c=a.style.pixelLeft;a.style.left=d;a.runtimeStyle.left=e;d=c}return d};function ed(a,b){return!!a&&1==a.nodeType&&(!b||a.tagName.toUpperCase()==b)}function fd(a){for(a=a.parentNode;a&&1!=a.nodeType&&9!=a.nodeType&&11!=a.nodeType;)a=a.parentNode;return ed(a)?a:null}
function gd(a,b){var c=ka(b);if("float"==c||"cssFloat"==c||"styleFloat"==c)c=ad?"styleFloat":"cssFloat";var d=bd(a,c)||hd(a,c);if(null===d)d=null;else if(ra(va,c)){b:{var e=d.match(ya);if(e){var c=Number(e[1]),f=Number(e[2]),g=Number(e[3]),e=Number(e[4]);if(0<=c&&255>=c&&0<=f&&255>=f&&0<=g&&255>=g&&0<=e&&1>=e){c=[c,f,g,e];break b}}c=null}if(!c){b:{if(g=d.match(za))if(c=Number(g[1]),f=Number(g[2]),g=Number(g[3]),0<=c&&255>=c&&0<=f&&255>=f&&0<=g&&255>=g){c=[c,f,g,1];break b}c=null}if(!c)b:{c=d.toLowerCase();
f=ua[c.toLowerCase()];if(!f&&(f="#"==c.charAt(0)?c:"#"+c,4==f.length&&(f=f.replace(wa,"#$1$1$2$2$3$3")),!xa.test(f))){c=null;break b}c=[parseInt(f.substr(1,2),16),parseInt(f.substr(3,2),16),parseInt(f.substr(5,2),16),1]}}d=c?"rgba("+c.join(", ")+")":d}return d}function hd(a,b){var c=a.currentStyle||a.style,d=c[b];void 0===d&&"function"==aa(c.getPropertyValue)&&(d=c.getPropertyValue(b));return"inherit"!=d?void 0!==d?d:null:(c=fd(a))?hd(c,b):null}
function id(a,b){function c(a){var b=gd(a,"position");if("fixed"==b)return G=!0,a==k?null:k;for(a=fd(a);a&&a!=k&&(0==gd(a,"display").lastIndexOf("inline",0)||"absolute"==b&&"static"==gd(a,"position"));)a=fd(a);return a}function d(a){var b=a;if("visible"==K)if(a==k&&q)b=q;else if(a==q)return{x:"visible",y:"visible"};b={x:gd(b,"overflow-x"),y:gd(b,"overflow-y")};a==k&&(b.x="visible"==b.x?"auto":b.x,b.y="visible"==b.y?"auto":b.y);return b}function e(a){if(a==k){var b=(new nb(g)).ia;a=Pa||"CSS1Compat"!=
b.compatMode?b.body||b.documentElement:b.documentElement;b=b.parentWindow||b.defaultView;a=w&&ab("10")&&b.pageYOffset!=a.scrollTop?new db(a.scrollLeft,a.scrollTop):new db(b.pageXOffset||a.scrollLeft,b.pageYOffset||a.scrollTop)}else a=new db(a.scrollLeft,a.scrollTop);return a}for(var f=jd(a,b),g=y(a),k=g.documentElement,q=g.body,K=gd(k,"overflow"),G,r=c(a);r;r=c(r)){var m=d(r);if("visible"!=m.x||"visible"!=m.y){var u=kd(r);if(0==u.width||0==u.height)return"hidden";var A=f.right<u.left,P=f.bottom<u.top;
if(A&&"hidden"==m.x||P&&"hidden"==m.y)return"hidden";if(A&&"visible"!=m.x||P&&"visible"!=m.y){A=e(r);P=f.bottom<u.top-A.y;if(f.right<u.left-A.x&&"visible"!=m.x||P&&"visible"!=m.x)return"hidden";f=id(r);return"hidden"==f?"hidden":"scroll"}A=f.left>=u.left+u.width;u=f.top>=u.top+u.height;if(A&&"hidden"==m.x||u&&"hidden"==m.y)return"hidden";if(A&&"visible"!=m.x||u&&"visible"!=m.y){if(G&&(m=e(r),f.left>=k.scrollWidth-m.x||f.right>=k.scrollHeight-m.y))return"hidden";f=id(r);return"hidden"==f?"hidden":
"scroll"}}}return"none"}var ld=RegExp("matrix\\(([\\d\\.\\-]+), ([\\d\\.\\-]+), ([\\d\\.\\-]+), ([\\d\\.\\-]+), ([\\d\\.\\-]+)(?:px)?, ([\\d\\.\\-]+)(?:px)?\\)");
function kd(a){function b(a){var c=(y(a)?y(a).parentWindow||y(a).defaultView:window).getComputedStyle(a,null).MozTransform.match(ld);if(c){var d=parseFloat(c[1]),e=parseFloat(c[2]),G=parseFloat(c[3]),r=parseFloat(c[4]),m=parseFloat(c[5]),c=parseFloat(c[6]),u=f.left+f.width,A=f.top+f.height,P=f.left*d,d=u*d,Ea=f.left*e,e=u*e,Fa=f.top*G,G=A*G,Ga=f.top*r,u=A*r,A=P+Fa+m,r=Ea+Ga+c,Fa=d+Fa+m,Ga=e+Ga+c,P=P+G+m,Ea=Ea+u+c,m=d+G+m,c=e+u+c;f.left=Math.min(A,Fa,P,m);f.top=Math.min(r,Ga,Ea,c);m=Math.max(A,Fa,
P,m);c=Math.max(r,Ga,Ea,c);f.width=m-f.left;f.height=c-f.top}(a=fd(a))&&b(a)}var c=md(a);if(c)return c.rect;if(ed(a,"HTML"))return c=y(a),a=ib((c?c.parentWindow||c.defaultView:window)||window),new X(0,0,a.width,a.height);var d;try{d=a.getBoundingClientRect()}catch(e){return new X(0,0,0,0)}var f=new X(d.left,d.top,d.right-d.left,d.bottom-d.top);w&&a.ownerDocument.body&&(c=y(a),f.left-=c.documentElement.clientLeft+c.body.clientLeft,f.top-=c.documentElement.clientTop+c.body.clientTop);v&&(0==f.width&&
0<a.offsetWidth&&(f.width=a.offsetWidth),0==f.height&&0<a.offsetHeight&&(f.height=a.offsetHeight));x&&!Vc(12)&&b(a);return f}
function md(a){var b=ed(a,"MAP");if(!b&&!ed(a,"AREA"))return null;var c=b?a:ed(a.parentNode,"MAP")?a.parentNode:null,d=null,e=null;if(c&&c.name&&(d=V.qa('/descendant::*[@usemap = "#'+c.name+'"]',y(c)))&&(e=kd(d),!b&&"default"!=a.shape.toLowerCase())){var f=nd(a);a=Math.min(Math.max(f.left,0),e.width);b=Math.min(Math.max(f.top,0),e.height);c=Math.min(f.width,e.width-a);f=Math.min(f.height,e.height-b);e=new X(a+e.left,b+e.top,c,f)}return{sa:d,rect:e||new X(0,0,0,0)}}
function nd(a){var b=a.shape.toLowerCase();a=a.coords.split(",");if("rect"==b&&4==a.length){var b=a[0],c=a[1];return new X(b,c,a[2]-b,a[3]-c)}if("circle"==b&&3==a.length)return b=a[2],new X(a[0]-b,a[1]-b,2*b,2*b);if("poly"==b&&2<a.length){for(var b=a[0],c=a[1],d=b,e=c,f=2;f+1<a.length;f+=2)b=Math.min(b,a[f]),d=Math.max(d,a[f]),c=Math.min(c,a[f+1]),e=Math.max(e,a[f+1]);return new X(b,c,d-b,e-c)}return new X(0,0,0,0)}
function jd(a,b){var c;c=kd(a);c=new W(c.top,c.left+c.width,c.top+c.height,c.left);if(b){var d=b instanceof X?b:new X(b.x,b.y,1,1);c.left=Math.min(Math.max(c.left+d.left,c.left),c.right);c.top=Math.min(Math.max(c.top+d.top,c.top),c.bottom);c.right=Math.min(Math.max(c.left+d.width,c.left),c.right);c.bottom=Math.min(Math.max(c.top+d.height,c.top),c.bottom)}return c};Pa||v||Wc&&Xc(3.6);w&&Vc(10);zb&&Xc(4);function Y(a,b){this.t={};this.g=[];var c=arguments.length;if(1<c){if(c%2)throw Error("Uneven number of arguments");for(var d=0;d<c;d+=2)this.set(arguments[d],arguments[d+1])}else if(a){var e;if(a instanceof Y)for(d=od(a),pd(a),e=[],c=0;c<a.g.length;c++)e.push(a.t[a.g[c]]);else{var c=[],f=0;for(d in a)c[f++]=d;d=c;c=[];f=0;for(e in a)c[f++]=a[e];e=c}for(c=0;c<d.length;c++)this.set(d[c],e[c])}}Y.prototype.A=0;Y.prototype.ea=0;function od(a){pd(a);return a.g.concat()}
Y.prototype.remove=function(a){return Object.prototype.hasOwnProperty.call(this.t,a)?(delete this.t[a],this.A--,this.ea++,this.g.length>2*this.A&&pd(this),!0):!1};function pd(a){if(a.A!=a.g.length){for(var b=0,c=0;b<a.g.length;){var d=a.g[b];Object.prototype.hasOwnProperty.call(a.t,d)&&(a.g[c++]=d);b++}a.g.length=c}if(a.A!=a.g.length){for(var e={},c=b=0;b<a.g.length;)d=a.g[b],Object.prototype.hasOwnProperty.call(e,d)||(a.g[c++]=d,e[d]=1),b++;a.g.length=c}}
Y.prototype.get=function(a,b){return Object.prototype.hasOwnProperty.call(this.t,a)?this.t[a]:b};Y.prototype.set=function(a,b){Object.prototype.hasOwnProperty.call(this.t,a)||(this.A++,this.g.push(a),this.ea++);this.t[a]=b};var qd={};function Z(a,b,c){ca(a)&&(a=x?a.b:v?a.opera:a.c);a=new rd(a,b,c);!b||b in qd&&!c||(qd[b]={key:a,shift:!1},c&&(qd[c]={key:a,shift:!0}));return a}function rd(a,b,c){this.code=a;this.ga=b||null;this.va=c||this.ga}Z(8);Z(9);Z(13);var sd=Z(16),td=Z(17),ud=Z(18);Z(19);Z(20);Z(27);Z(32," ");Z(33);Z(34);Z(35);Z(36);Z(37);Z(38);Z(39);Z(40);Z(44);Z(45);Z(46);Z(48,"0",")");Z(49,"1","!");Z(50,"2","@");Z(51,"3","#");Z(52,"4","$");Z(53,"5","%");Z(54,"6","^");Z(55,"7","&");Z(56,"8","*");Z(57,"9","(");
Z(65,"a","A");Z(66,"b","B");Z(67,"c","C");Z(68,"d","D");Z(69,"e","E");Z(70,"f","F");Z(71,"g","G");Z(72,"h","H");Z(73,"i","I");Z(74,"j","J");Z(75,"k","K");Z(76,"l","L");Z(77,"m","M");Z(78,"n","N");Z(79,"o","O");Z(80,"p","P");Z(81,"q","Q");Z(82,"r","R");Z(83,"s","S");Z(84,"t","T");Z(85,"u","U");Z(86,"v","V");Z(87,"w","W");Z(88,"x","X");Z(89,"y","Y");Z(90,"z","Z");var vd=Z(La?{b:91,c:91,opera:219}:Ka?{b:224,c:91,opera:17}:{b:0,c:91,opera:null});
Z(La?{b:92,c:92,opera:220}:Ka?{b:224,c:93,opera:17}:{b:0,c:92,opera:null});Z(La?{b:93,c:93,opera:0}:Ka?{b:0,c:0,opera:16}:{b:93,c:null,opera:0});Z({b:96,c:96,opera:48},"0");Z({b:97,c:97,opera:49},"1");Z({b:98,c:98,opera:50},"2");Z({b:99,c:99,opera:51},"3");Z({b:100,c:100,opera:52},"4");Z({b:101,c:101,opera:53},"5");Z({b:102,c:102,opera:54},"6");Z({b:103,c:103,opera:55},"7");Z({b:104,c:104,opera:56},"8");Z({b:105,c:105,opera:57},"9");Z({b:106,c:106,opera:Sa?56:42},"*");
Z({b:107,c:107,opera:Sa?61:43},"+");Z({b:109,c:109,opera:Sa?109:45},"-");Z({b:110,c:110,opera:Sa?190:78},".");Z({b:111,c:111,opera:Sa?191:47},"/");Z(Sa&&v?null:144);Z(112);Z(113);Z(114);Z(115);Z(116);Z(117);Z(118);Z(119);Z(120);Z(121);Z(122);Z(123);Z({b:107,c:187,opera:61},"=","+");Z(108,",");Z({b:109,c:189,opera:109},"-","_");Z(188,",","<");Z(190,".",">");Z(191,"/","?");Z(192,"`","~");Z(219,"[","{");Z(220,"\\","|");Z(221,"]","}");Z({b:59,c:186,opera:59},";",":");Z(222,"'",'"');var wd=new Y;
wd.set(1,sd);wd.set(2,td);wd.set(4,ud);wd.set(8,vd);(function(a){var b=new Y;t(od(a),function(c){b.set(a.get(c).code,c)});return b})(wd);x&&Vc(12);function xd(a,b){var c=id(a,b);if("scroll"!=c)return"none"==c;if(a.scrollIntoView&&(a.scrollIntoView(),"none"==id(a,b)))return!0;for(var c=jd(a,b),d=fd(a);d;d=fd(d)){var e=d,f=kd(e),g;var k=e;if(!w||w&&9<=cb)q=bd(k,"borderLeftWidth"),g=bd(k,"borderRightWidth"),K=bd(k,"borderTopWidth"),k=bd(k,"borderBottomWidth"),g=new W(parseFloat(K),parseFloat(g),parseFloat(k),parseFloat(q));else{var q=dd(k,"borderLeft");g=dd(k,"borderRight");var K=dd(k,"borderTop"),k=dd(k,"borderBottom");g=new W(K,g,k,q)}q=c.left-
f.left-g.left;f=c.top-f.top-g.top;g=e.clientHeight+c.top-c.bottom;e.scrollLeft+=Math.min(q,Math.max(q-(e.clientWidth+c.left-c.right),0));e.scrollTop+=Math.min(f,Math.max(f-g,0))}return"none"==id(a,b)};function yd(){this.I=void 0}
function zd(a,b,c){switch(typeof b){case "string":Ad(b,c);break;case "number":c.push(isFinite(b)&&!isNaN(b)?b:"null");break;case "boolean":c.push(b);break;case "undefined":c.push("null");break;case "object":if(null==b){c.push("null");break}if("array"==aa(b)){var d=b.length;c.push("[");for(var e="",f=0;f<d;f++)c.push(e),e=b[f],zd(a,a.I?a.I.call(b,String(f),e):e,c),e=",";c.push("]");break}c.push("{");d="";for(f in b)Object.prototype.hasOwnProperty.call(b,f)&&(e=b[f],"function"!=typeof e&&(c.push(d),
Ad(f,c),c.push(":"),zd(a,a.I?a.I.call(b,f,e):e,c),d=","));c.push("}");break;case "function":break;default:throw Error("Unknown type: "+typeof b);}}var Bd={'"':'\\"',"\\":"\\\\","/":"\\/","\b":"\\b","\f":"\\f","\n":"\\n","\r":"\\r","\t":"\\t","\x0B":"\\u000b"},Cd=/\uffff/.test("\uffff")?/[\\\"\x00-\x1f\x7f-\uffff]/g:/[\\\"\x00-\x1f\x7f-\xff]/g;
function Ad(a,b){b.push('"',a.replace(Cd,function(a){if(a in Bd)return Bd[a];var b=a.charCodeAt(0),e="\\u";16>b?e+="000":256>b?e+="00":4096>b&&(e+="0");return Bd[a]=e+b.toString(16)}),'"')};Pa||v||x&&Vc(3.5)||w&&Vc(8);function Dd(a){switch(aa(a)){case "string":case "number":case "boolean":return a;case "function":return a.toString();case "array":return na(a,Dd);case "object":if("nodeType"in a&&(1==a.nodeType||9==a.nodeType)){var b={};b.ELEMENT=Ed(a);return b}if("document"in a)return b={},b.WINDOW=Ed(a),b;if(ba(a))return na(a,Dd);a=fb(a,function(a,b){return"number"==typeof b||p(b)});return gb(a,Dd);default:return null}}
function Fd(a,b){return"array"==aa(a)?na(a,function(a){return Fd(a,b)}):ca(a)?"function"==typeof a?a:"ELEMENT"in a?Gd(a.ELEMENT,b):"WINDOW"in a?Gd(a.WINDOW,b):gb(a,function(a){return Fd(a,b)}):a}function Hd(a){a=a||document;var b=a.$wdc_;b||(b=a.$wdc_={},b.Q=ha());b.Q||(b.Q=ha());return b}function Ed(a){var b=Hd(a.ownerDocument),c=hb(b,function(b){return b==a});c||(c=":wdc:"+b.Q++,b[c]=a);return c}
function Gd(a,b){a=decodeURIComponent(a);var c=b||document,d=Hd(c);if(!(a in d))throw new Aa(10,"Element does not exist in cache");var e=d[a];if("setInterval"in e){if(e.closed)throw delete d[a],new Aa(23,"Window has been closed.");return e}for(var f=e;f;){if(f==c.documentElement)return e;f=f.parentNode}delete d[a];throw new Aa(10,"Element is no longer attached to the DOM");};function Id(a,b){var c=[a,b],d=xd,e;try{var d=p(d)?new ia.Function(d):ia==window?d:new ia.Function("return ("+d+").apply(null,arguments);"),f=Fd(c,ia.document),g=d.apply(null,f);e={status:0,value:Dd(g)}}catch(k){e={status:"code"in k?k.code:13,value:{message:k.message}}}c=[];zd(new yd,e,c);return c.join("")}var Jd=["_"],$=n;Jd[0]in $||!$.execScript||$.execScript("var "+Jd[0]);for(var Kd;Jd.length&&(Kd=Jd.shift());)Jd.length||void 0===Id?$=$[Kd]?$[Kd]:$[Kd]={}:$[Kd]=Id;; return this._.apply(null,arguments);}.apply({navigator:typeof window!=undefined?window.navigator:null,document:typeof window!=undefined?window.document:null}, arguments);}
